@@ -7,12 +7,14 @@ import sys
 from selenium import webdriver
 from selenium.webdriver.remote.webdriver import RemoteConnection
 from appium import webdriver as mobile_webdriver
+from appium.options.android import UiAutomator2Options
 from ..utils import remote_credentials, screenshot_conf
 from ..drivers.browsers.remote_options import RemoteOptions
 from ..drivers.browsers.local_browsers import LocalBrowsers
 
+
 from ..conf.app import ports_conf     # use for local mobile tests
-localhost_url = 'http://localhost:%s/wd/hub' % ports_conf.port    # Set the url of localhost
+localhost_url = 'http://localhost:%s' % ports_conf.port    # Set the url of localhost
 
 
 class DriverFactory(RemoteOptions, LocalBrowsers):
@@ -25,7 +27,7 @@ class DriverFactory(RemoteOptions, LocalBrowsers):
         self.os_name = os_name
 
     def get_web_driver(self, remote_flag, os_name, os_version, browser,
-                       browser_version, remote_project_name, remote_build_name):
+                       browser_version, remote_project_name, remote_build_name, wdm):
         """Return the appropriate driver."""
         web_driver = None
         if remote_flag.lower() == 'y':
@@ -34,7 +36,7 @@ class DriverFactory(RemoteOptions, LocalBrowsers):
                                                      remote_build_name)
 
         elif remote_flag.lower() == 'n':
-            web_driver = self.run_local(browser)
+            web_driver = self.run_local(browser, wdm)
 
         return web_driver
 
@@ -128,13 +130,13 @@ class DriverFactory(RemoteOptions, LocalBrowsers):
 
         return web_driver
 
-    def run_local(self, browser):
+    def run_local(self, browser, wdm):
         """Run the test on local system."""
         local_driver = None
         if browser.lower() == "chrome":
-            local_driver = self.chrome_local()
+            local_driver = self.chrome_local(wdm)
         elif browser.lower() == "headless-chrome":
-            local_driver = self.headless_chrome()
+            local_driver = self.headless_chrome(wdm)
         elif browser.lower() == "ff" or browser.lower() == 'firefox':
             local_driver = self.firefox_local()
         elif browser.lower() == "ie":
@@ -191,11 +193,13 @@ class DriverFactory(RemoteOptions, LocalBrowsers):
                 desired_capabilities['appPackage'] = app_package
                 desired_capabilities['appActivity'] = app_activity
                 desired_capabilities['noReset'] = True if no_reset_flag.lower() == 'true' else False
+                desired_capabilities['automationName'] = "uiautomator2"
+                capabilities_options = UiAutomator2Options().load_capabilities(desired_capabilities)
                 if device_flag.lower() == 'y':
-                    mobile_driver = mobile_webdriver.Remote(localhost_url, desired_capabilities)
+                    mobile_driver = mobile_webdriver.Remote(localhost_url, capabilities_options)
                 else:
                     desired_capabilities['app'] = os.path.join(app_path, app_name)
-                    mobile_driver = mobile_webdriver.Remote(localhost_url, desired_capabilities)
+                    mobile_driver = mobile_webdriver.Remote(localhost_url, capabilities_options)
 
             except Exception as exception:
                 self.print_exception(exception, remote_flag)
